##  Mapping Fact Sheet Attributes and Dictionary Item Fields
You map the fact sheet attributes and dictionary item fields using field mapping settings. In the Actions column, click the field mapping icon next to the delete button to open the field mapping modal.
![Click the Field Mapping Icon to Open the Settings](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27477ef67a44101483b8afe8752d1c22_LowRes.png)
Click the Field Mapping Icon to Open the Settings
Based on best practice data from SAP LeanIX, field mapping suggestions are given at the top. You can simply select a suggestion to add it to your list of field mappings. Additionally, you can manually define mappings by clicking Add and choosing fact sheet attributes and corresponding dictionary item fields from the respective drop-down lists.
![Field Mapping Settings](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274da5bd7a4410149c0fe13d74650e69_LowRes.png)
Field Mapping Settings
For SAP LeanIX fact sheets, the available attributes include:
  * Scalar fields (e.g., text, number)
  * Single-select fields
  * Multi-select fields
  * Date fields
  * Subscriptions and subscription roles
  * Tags and tag groups


For SAP Signavio, you can select from:
  * Fields on dictionary items
  * Scalar fields (e.g., text, number, date)
  * Single-select and multi-select fields


**Tip**
Lifecycle Dates
Lifecycle phases are mapped to date fields in SAP Signavio. During synchronization, SAP LeanIX automatically converts the dates to SAP Signavio's different date formats.
